==> modeshape-jcr-1.0.0.Final-sources.jar: org/modeshape/jcr/nodetype/InvalidNodeTypeDefinitionException.java <==
/*
 * ModeShape (http://www.modeshape.org)
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * See the AUTHORS.txt file in the distribution for a full listing of 
 * individual contributors.
 *
 * ModeShape is free software. Unless otherwise indicated, all code in ModeShape
 * is licensed to you under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 * 
 * ModeShape is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.modeshape.jcr.nodetype;

import javax.jcr.RepositoryException;
import net.jcip.annotations.Immutable;

/**
 * Exception representing that a node type definition is somehow invalid
 */
@Immutable
public class InvalidNodeTypeDefinitionException extends RepositoryException {

    /**
     */
    private static final long serialVersionUID = 1L;

    /**
     * 
     */
    public InvalidNodeTypeDefinitionException() {
        super();

    }

    /**
     * @param message
     * @param rootCause
     */
    public InvalidNodeTypeDefinitionException( String message,
                                               Throwable rootCause ) {
        super(message, rootCause);

    }

    /**
     * @param message
     */
    public InvalidNodeTypeDefinitionException( String message ) {
        super(message);

    }

    /**
     * @param rootCause
     */
    public InvalidNodeTypeDefinitionException( Throwable rootCause ) {
        super(rootCause);

    }

}

==> modeshape-jcr-2.4.0.Final-sources.jar: org/modeshape/jcr/nodetype/InvalidNodeTypeDefinitionException.java <==
/*
 * ModeShape (http://www.modeshape.org)
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * See the AUTHORS.txt file in the distribution for a full listing of 
 * individual contributors.
 *
 * ModeShape is free software. Unless otherwise indicated, all code in ModeShape
 * is licensed to you under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 * 
 * ModeShape is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.modeshape.jcr.nodetype;

import net.jcip.annotations.Immutable;

/**
 * Exception representing that a node type definition is somehow invalid
 */
@Immutable
public class InvalidNodeTypeDefinitionException extends javax.jcr.nodetype.InvalidNodeTypeDefinitionException {

    /**
     */
    private static final long serialVersionUID = 1L;

    /**
     * 
     */
    public InvalidNodeTypeDefinitionException() {
        super();

    }

    /**
     * @param message
     * @param rootCause
     */
    public InvalidNodeTypeDefinitionException( String message,
                                               Throwable rootCause ) {
        super(message, rootCause);

    }

    /**
     * @param message
     */
    public InvalidNodeTypeDefinitionException( String message ) {
        super(message);

    }

    /**
     * @param rootCause
     */
    public InvalidNodeTypeDefinitionException( Throwable rootCause ) {
        super(rootCause);

    }

}
